@@ -6,7 +6,7 @@ Kafka::IO - Interface to network communication with the Apache Kafka server.
 
 =head1 VERSION
 
-This documentation refers to C<Kafka::IO> version 0.8008 .
+This documentation refers to C<Kafka::IO> version 0.8009 .
 
 =cut
 
@@ -16,13 +16,11 @@ use 5.010;
 use strict;
 use warnings;
 
-use sigtrap;
-
 # ENVIRONMENT ------------------------------------------------------------------
 
 our $DEBUG = 0;
 
-our $VERSION = '0.8008';
+our $VERSION = '0.8009';
 
 #-- load the modules -----------------------------------------------------------
 
@@ -191,6 +189,10 @@ sub new {
         $self->{ $k } = shift @args if exists $self->{ $k };
     }
 
+    # we trust it: make it untainted
+    ( $self->{host} ) = $self->{host} =~ /\A(.+)\z/;
+    ( $self->{port} ) = $self->{port} =~ /\A(\d+)\z/;
+
     $self->{not_accepted} = 0;
     $self->{socket} = undef;
     try {
@@ -277,6 +279,8 @@ sub receive {
 
     $self->_debug_msg( $message, 'Response from', 'yellow' )
         if $self->debug_level >= 2;
+
+    # returns tainted data
     return \$message;
 }
 
